'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = transformFlowStripTypesImportFix;

var _babelPluginSyntaxFlow = require('babel-plugin-syntax-flow');

var _babelPluginSyntaxFlow2 = _interopRequireDefault(_babelPluginSyntaxFlow);

var _flowRuntime = require('flow-runtime');

var _flowRuntime2 = _interopRequireDefault(_flowRuntime);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * TEMP_FIX (babel 6.x) for import { type A, type B } from 'moduleA';
 * getting converted to  "import 'moduleA';" but it should be removed
 *
 * the current fix is already present in babel plugin v7 so remove
 * when upgrade to babel 7
 */
function transformFlowStripTypesImportFix() {
  return {
    inherits: _babelPluginSyntaxFlow2.default,

    visitor: {
      ImportDeclaration: function ImportDeclaration(path) {
        var _pathType = _flowRuntime2.default.object();

        _flowRuntime2.default.param('path', _pathType).assert(path);

        if (!path.node.specifiers.length) {
          return;
        }

        var typeCount = 0;

        path.node.specifiers.forEach(function (_ref) {
          var importKind = _ref.importKind;

          if (importKind === 'type' || importKind === 'typeof') {
            typeCount += 1;
          }
        });

        if (typeCount === path.node.specifiers.length) {
          path.remove();
        }
      }
    }
  };
}